==> libguestfs-1.22.9.tar.gz: libguestfs-1.22.9/tests/regressions/rhbz1001875.sh <==
#!/bin/bash -
# libguestfs
# Copyright (C) 2013 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Regression test for:
# https://bugzilla.redhat.com/show_bug.cgi?id=1001875
# tar-out excludes option.

set -e
export LANG=C

if [ -n "$SKIP_TEST_RHBZ1001875_SH" ]; then
    echo "$0: test skipped because environment variable is set."
    exit 77
fi

rm -f test1.img rhbz1001875-[123].tar

../../fish/guestfish -N fs -m /dev/sda1 <<EOF
touch /hello
touch /world
touch /helloworld
tar-out / rhbz1001875-1.tar "excludes:hello"
tar-out / rhbz1001875-2.tar "excludes:hello world"
tar-out / rhbz1001875-3.tar "excludes:he* w*"
EOF

if [ "$(tar tf rhbz1001875-1.tar | sort)" != "./
./helloworld
./lost+found/
./world" ]; then
    echo "$0: unexpected output from #1 test:"
    tar tf rhbz1001875-1.tar | sort
    exit 1
fi

if [ "$(tar tf rhbz1001875-2.tar | sort)" != "./
./helloworld
./lost+found/" ]; then
    echo "$0: unexpected output from #2 test:"
    tar tf rhbz1001875-2.tar | sort
    exit 1
fi

if [ "$(tar tf rhbz1001875-3.tar | sort)" != "./
./lost+found/" ]; then
    echo "$0: unexpected output from #3 test:"
    tar tf rhbz1001875-3.tar | sort
    exit 1
fi

rm test1.img rhbz1001875-[123].tar

==> libguestfs_1.25.46.orig.tar.gz: libguestfs-1.25.46/tests/regressions/rhbz1001875.sh <==
#!/bin/bash -
# libguestfs
# Copyright (C) 2013 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Regression test for:
# https://bugzilla.redhat.com/show_bug.cgi?id=1001875
# tar-out excludes option.

set -e
export LANG=C

if [ -n "$SKIP_TEST_RHBZ1001875_SH" ]; then
    echo "$0: test skipped because environment variable is set."
    exit 77
fi

rm -f rhbz1001875.img rhbz1001875-[123].tar

../../fish/guestfish -N rhbz1001875.img=fs -m /dev/sda1 <<EOF
touch /hello
touch /world
touch /helloworld
tar-out / rhbz1001875-1.tar "excludes:hello"
tar-out / rhbz1001875-2.tar "excludes:hello world"
tar-out / rhbz1001875-3.tar "excludes:he* w*"
EOF

if [ "$(tar tf rhbz1001875-1.tar | sort)" != "./
./helloworld
./lost+found/
./world" ]; then
    echo "$0: unexpected output from #1 test:"
    tar tf rhbz1001875-1.tar | sort
    exit 1
fi

if [ "$(tar tf rhbz1001875-2.tar | sort)" != "./
./helloworld
./lost+found/" ]; then
    echo "$0: unexpected output from #2 test:"
    tar tf rhbz1001875-2.tar | sort
    exit 1
fi

if [ "$(tar tf rhbz1001875-3.tar | sort)" != "./
./lost+found/" ]; then
    echo "$0: unexpected output from #3 test:"
    tar tf rhbz1001875-3.tar | sort
    exit 1
fi

rm rhbz1001875.img rhbz1001875-[123].tar
